==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/oc/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Occitan',

# common
'L_PLUXML_VERSION'				=> 'Pluxml version',
'L_HOMEPAGE'					=> 'Acuèlh',
'L_UNCLASSIFIED'				=> 'Non classat',
'L_INFO_PHP_VERSION'			=> 'Version de php',
'L_INFO_MAGIC_QUOTES'			=> 'Estat dels "magic quotes"',
'L_INFO_CHARSET'				=> 'encodatge',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Lo tèma principal de PluXml es introbable',
'L_ERR_FILE_NOTFOUND'			=> 'Lo fichièr cibla de PluXml es introbable',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina non trobada',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'gen',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'març',
'L_SHORT_APRIL'					=> 'abril',
'L_SHORT_MAY'					=> 'mai',
'L_SHORT_JUNE'					=> 'junh',
'L_SHORT_JULY'					=> 'julh',
'L_SHORT_AUGUST'				=> 'agost',
'L_SHORT_SEPTEMBER'				=> 'set',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'genièr',
'L_FEBRUARY'					=> 'febrièr',
'L_MARCH'						=> 'març',
'L_APRIL'						=> 'abril',
'L_MAY'							=> 'mai',
'L_JUNE'						=> 'junh',
'L_JULY'						=> 'julhet',
'L_AUGUST'						=> 'agost',
'L_SEPTEMBER'					=> 'setembre',
'L_OCTOBER'						=> 'octòbre',
'L_NOVEMBER'					=> 'novembre',
'L_DECEMBER'					=> 'decembre',
'L_MONDAY'						=> 'diluns',
'L_TUESDAY'						=> 'dimars',
'L_WEDNESDAY'					=> 'dimècres',
'L_THURSDAY'					=> 'dijòus',
'L_FRIDAY'						=> 'divendres',
'L_SATURDAY'					=> 'dissabte',
'L_SUNDAY'						=> 'dimenge',

# class.plx.capcha.php
'L_LAST'						=> 'darrièra',
'L_FIRST'						=> 'primièra',
'L_SECOND'						=> 'segonda',
'L_THIRD'						=> 'tresena',
'L_FOURTH'						=> 'quatrena',
'L_FIFTH'						=> 'cinquena',
'L_SIXTH'						=> 'seisena',
'L_SEVENTH'						=> 'setena',
'L_EIGTH'						=> 'ochena',
'L_NINTH'						=> 'novena',
'L_TENTH'						=> 'desena',
'L_NTH'							=> 'ena',
'L_CAPCHA_QUESTION'				=> 'Quina es la <span class="capcha-letter">%s</span> letra del mot <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s es accessible en escritura',
'L_WRITE_NOT_ACCESS'			=> '%s es pas accessible en escritura o existís pas',
'L_MODREWRITE_AVAILABLE'		=> 'Modul apache de reescritura d\'url mod_rewrite disponible',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Modul apache de reescritura d\'url mod_rewrite non disponible',
'L_LIBGD_INSTALLED'				=> 'Bibliotèca GD installada',
'L_LIBGD_NOT_INSTALLED'			=> 'Bibliotèca GD non installada',
'L_MAIL_AVAILABLE'				=> 'Foncion d\'enviada de mail disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Foncion d\'enviada de mail non disponible',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Lo fichièr "%sversion" es necessari al foncionament de PluXml',
'L_ARTICLE_NO_TAG'				=> 'Pas cap d\'article per aqueste mot clau !',
'L_UNKNOWN_CATEGORY'			=> 'Aquesta categoria es inexistenta !',
'L_NO_ARTICLE_PAGE'				=> 'Pas cap d\'article per aquesta pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Aqueste article existís pas o existís pas mai !',
'L_COM_IN_MODERATION'			=> 'Lo comentari es per se far moderar per l\'administrator d\'aquel siti',
'L_UNKNOWN_STATIC'				=> 'Aquesta pagina existís pas o existís pas mai !',
'L_DOCUMENT_NOT_FOUND'			=> 'Lo document especificat es introbable',
'L_NEWCOMMENT_ERR'				=> 'Una error s\'es produsida al temps de la publicacion d\'aquel comentari',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Mercés d\'emplir totes los camps obligatòris requesits',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'La verificacion anti-spam s\'es abocada',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compression %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Archius',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'pas cap de categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorias',
'L_NO_ARTICLE'					=> 'pas cap d\'article',
'L_ARTICLE'						=> 'article',
'L_ARTICLES'					=> 'articles',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconegut',
'L_ARTTAGS_NONE'				=> 'cap',
'L_ARTCHAPO'					=> 'Legir la seguida de #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Fil Rss dels articles d\'aquesta categoria',
'L_ARTFEED_RSS_TAG'				=> 'Fil Rss dels articles d\'aqueste mot clau',
'L_ARTFEED_RSS'					=> 'Fil Rss dels articles',
'L_NO_COMMENT'					=> 'pas cap de comentari',
'L_COMMENT'						=> 'comentari',
'L_COMMENTS'					=> 'comentaris',
'L_COMFEED_RSS_ARTICLE'			=> 'Fil Rss dels comentaris d\'aquel article',
'L_COMFEED_RSS'					=> 'Fil Rss dels comentaris',
'L_STATICCONTENT_INPROCESS'		=> 'Aquesta pagina es actualament per èsser redigida',
'L_SAID'						=> 'a dich',

'L_PAGINATION_FIRST_TITLE'		=> 'Anar a la primièra pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina precedenta',
'L_PAGINATION_PREVIOUS'			=> 'precedenta',
'L_PAGINATION_NEXT_TITLE'		=> 'pagina seguenta',
'L_PAGINATION_NEXT'				=> 'seguenta',
'L_PAGINATION_LAST_TITLE'		=> 'Anar a la darrièra pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s sus %s',

'L_PAGEBLOG_TITLE'				=> 'Blòg',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Las URLs privadas son pas estadas inicializadas dins vòstres paramètres d\'administracion !',
'L_FEED_COMMENTS'				=> 'Comentaris',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentaris en linha',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentaris fòra linha',
'L_FEED_WRITTEN_BY'				=> 'Redigit per',
);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/oc/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Occitan',

'L_DATE_CREATION'				=> 'Data de creacion',
'L_DATE_UPDATE'					=> 'Data de misa a jorn',

# common
'L_PLUXML_VERSION'				=> 'Pluxml version',
'L_HOMEPAGE'					=> 'Acuèlh',
'L_UNCLASSIFIED'				=> 'Non classat',
'L_INFO_PHP_VERSION'			=> 'Version de php',
'L_INFO_MAGIC_QUOTES'			=> 'Estat dels "magic quotes"',
'L_INFO_CHARSET'				=> 'encodatge',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Lo tèma principal de PluXml es introbable',
'L_ERR_FILE_NOTFOUND'			=> 'Lo fichièr cibla de PluXml es introbable',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina non trobada',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'gen',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'març',
'L_SHORT_APRIL'					=> 'abril',
'L_SHORT_MAY'					=> 'mai',
'L_SHORT_JUNE'					=> 'junh',
'L_SHORT_JULY'					=> 'julh',
'L_SHORT_AUGUST'				=> 'agost',
'L_SHORT_SEPTEMBER'				=> 'set',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'genièr',
'L_FEBRUARY'					=> 'febrièr',
'L_MARCH'						=> 'març',
'L_APRIL'						=> 'abril',
'L_MAY'							=> 'mai',
'L_JUNE'						=> 'junh',
'L_JULY'						=> 'julhet',
'L_AUGUST'						=> 'agost',
'L_SEPTEMBER'					=> 'setembre',
'L_OCTOBER'						=> 'octòbre',
'L_NOVEMBER'					=> 'novembre',
'L_DECEMBER'					=> 'decembre',
'L_MONDAY'						=> 'diluns',
'L_TUESDAY'						=> 'dimars',
'L_WEDNESDAY'					=> 'dimècres',
'L_THURSDAY'					=> 'dijòus',
'L_FRIDAY'						=> 'divendres',
'L_SATURDAY'					=> 'dissabte',
'L_SUNDAY'						=> 'dimenge',

# class.plx.capcha.php
'L_LAST'						=> 'darrièra',
'L_FIRST'						=> 'primièra',
'L_SECOND'						=> 'segonda',
'L_THIRD'						=> 'tresena',
'L_FOURTH'						=> 'quatrena',
'L_FIFTH'						=> 'cinquena',
'L_SIXTH'						=> 'seisena',
'L_SEVENTH'						=> 'setena',
'L_EIGTH'						=> 'ochena',
'L_NINTH'						=> 'novena',
'L_TENTH'						=> 'desena',
'L_NTH'							=> 'ena',
'L_CAPCHA_QUESTION'				=> 'Quina es la <span class="capcha-letter">%s</span> letra del mot <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s es accessible en escritura',
'L_WRITE_NOT_ACCESS'			=> '%s es pas accessible en escritura o existís pas',
'L_MODREWRITE_AVAILABLE'		=> 'Modul apache de reescritura d\'url mod_rewrite disponible',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Modul apache de reescritura d\'url mod_rewrite non disponible',
'L_LIBGD_INSTALLED'				=> 'Bibliotèca GD installada',
'L_LIBGD_NOT_INSTALLED'			=> 'Bibliotèca GD non installada',
'L_MAIL_AVAILABLE'				=> 'Foncion d\'enviada de mail disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Foncion d\'enviada de mail non disponible',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Pas cap d\'article per aqueste mot clau !',
'L_UNKNOWN_CATEGORY'			=> 'Aquesta categoria es inexistenta !',
'L_NO_ARTICLE_PAGE'				=> 'Pas cap d\'article per aquesta pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Aqueste article existís pas o existís pas mai !',
'L_COM_IN_MODERATION'			=> 'Lo comentari es per se far moderar per l\'administrator d\'aquel siti',
'L_UNKNOWN_STATIC'				=> 'Aquesta pagina existís pas o existís pas mai !',
'L_DOCUMENT_NOT_FOUND'			=> 'Lo document especificat es introbable',
'L_NEWCOMMENT_ERR'				=> 'Una error s\'es produsida al temps de la publicacion d\'aquel comentari',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Mercés d\'emplir totes los camps obligatòris requesits',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'La verificacion anti-spam s\'es abocada',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compression %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Archius',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'pas cap de categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorias',
'L_NO_ARTICLE'					=> 'pas cap d\'article',
'L_ARTICLE'						=> 'article',
'L_ARTICLES'					=> 'articles',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconegut',
'L_ARTTAGS_NONE'				=> 'cap',
'L_ARTCHAPO'					=> 'Legir la seguida de #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Fil Rss dels articles d\'aquesta categoria',
'L_ARTFEED_RSS_TAG'				=> 'Fil Rss dels articles d\'aqueste mot clau',
'L_ARTFEED_RSS'					=> 'Fil Rss dels articles',
'L_NO_COMMENT'					=> 'pas cap de comentari',
'L_COMMENT'						=> 'comentari',
'L_COMMENTS'					=> 'comentaris',
'L_COMFEED_RSS_ARTICLE'			=> 'Fil Rss dels comentaris d\'aquel article',
'L_COMFEED_RSS'					=> 'Fil Rss dels comentaris',
'L_STATICCONTENT_INPROCESS'		=> 'Aquesta pagina es actualament per èsser redigida',
'L_SAID'						=> 'a dich',

'L_PAGINATION_FIRST_TITLE'		=> 'Anar a la primièra pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina precedenta',
'L_PAGINATION_PREVIOUS'			=> 'precedenta',
'L_PAGINATION_NEXT_TITLE'		=> 'pagina seguenta',
'L_PAGINATION_NEXT'				=> 'seguenta',
'L_PAGINATION_LAST_TITLE'		=> 'Anar a la darrièra pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s sus %s',

'L_PAGEBLOG_TITLE'				=> 'Blòg',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Las URLs privadas son pas estadas inicializadas dins vòstres paramètres d\'administracion !',
'L_FEED_COMMENTS'				=> 'Comentaris',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentaris en linha',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentaris fòra linha',
'L_FEED_WRITTEN_BY'				=> 'Redigit per',
);
?>
